@@ -1,4 +1,4 @@
-from django.utils.formats import number_format
+from django.utils import numberformat
 from decimal import Decimal, ROUND_HALF_UP
 
 def format_price(price, currency, decimal_pos=None):
@@ -14,12 +14,16 @@ def format_price(price, currency, decimal_pos=None):
     else:
         exp = Decimal('1.0') / (Decimal(10) ** abs(decimal_pos))
 
-    formatted_price = number_format(u'%s' % str(d.quantize(exp, ROUND_HALF_UP)), abs(decimal_pos))
-#    formatted_price = formatted_price.replace(' ', '&nbsp;')
+    formatted_price = numberformat.format(
+        u'%s' % str(d.quantize(exp, ROUND_HALF_UP)), currency.decimal_separator,
+        abs(decimal_pos), grouping=3, thousand_sep=currency.thousand_separator)
     
     if currency.symbol_preceeds:
         params = (currency.symbol, formatted_price)
     else:
         params = (formatted_price, currency.symbol)
     return u'%s %s' % params
-#    return u'%s&nbsp;%s' % params
+
+
+def convert_price(amount, curr_from, curr_to):
+    return amount / curr_from.factor * curr_to.factor
\ No newline at end of file
